PsecError

Enum PsecError 

pub enum PsecError {
    BrokenPipe,
    ConnectionReset,
    TransmissionCorrupted,
    BufferTooLarge,
    UnexpectedEof,
    IoError {
        error_kind: ErrorKind,
    },
    BadPadding,
}
Errors that can be returned by PSEC operations.

Variants



BrokenPipe

The operation failed because a pipe was closed.



ConnectionReset

The connection was reset by the remote peer.



TransmissionCorrupted

Authentication error. It often means that the AES GCM tag was invalid during a decryption operation.



BufferTooLarge

The received buffer was too large and was discarded to prevent DOS attacks.



UnexpectedEof

Failed to read the desired amout of bytes.



IoError

An unknown error occurred while reading or writing to the underlying TcpStream.

Fields

error_kind: ErrorKind

The ErrorKind of the I/O Error.



BadPadding

The plain text was not properly padded.